@@ -37,6 +37,7 @@ class CloneMixin(six.with_metaclass(CloneMetaClass)):
     _clonable_one_to_one_fields = []
 
     UNIQUE_DUPLICATE_SUFFIX = 'copy'
+    USE_UNIQUE_DUPLICATE_SUFFIX = True
 
     @property
     @abc.abstractmethod
@@ -46,7 +47,8 @@ class CloneMixin(six.with_metaclass(CloneMetaClass)):
     @classmethod
     def _create_copy_of_instance(cls, instance):
         defaults = {}
-        fields = instance._meta.concrete_fields
+        fields = [f for f in instance._meta.concrete_fields if not f.primary_key]
+
         if cls._clonable_model_fields:
             fields = [f for f in fields if f.name in cls._clonable_model_fields]
 
@@ -74,8 +76,9 @@ class CloneMixin(six.with_metaclass(CloneMetaClass)):
                         .filter(**{'{}__startswith'.format(f.attname): value})
                         .count()
                     )
-                    if not str(value).isdigit():
-                        value += ' {} {}'.format(cls.UNIQUE_DUPLICATE_SUFFIX, count)
+                    if cls.USE_UNIQUE_DUPLICATE_SUFFIX:
+                        if not str(value).isdigit():
+                            value += ' {} {}'.format(cls.UNIQUE_DUPLICATE_SUFFIX, count)
                     if isinstance(f, SlugField):
                         value = slugify(value)
                 defaults[f.attname] = value
@@ -112,8 +115,8 @@ class CloneMixin(six.with_metaclass(CloneMetaClass)):
         ]
 
         many_to_one_or_one_to_many_fields = [
-            f.name for f in self._meta.related_objects
-            if any([f.many_to_one, f.one_to_many, f.one_to_one])
+            f for f in self._meta.related_objects
+            if any([f.many_to_one, f.one_to_many])
             and f.name in self._clonable_many_to_one_or_one_to_many_fields
         ]
 
